@@ -9,6 +9,7 @@ use Sub::Exporter -setup => {
     exports => [qw[
         looks_like_uid
         expand_uid
+        expand_uri
         serialize_record
         deserialize_record
         error_as_json
@@ -48,6 +49,15 @@ sub expand_uid {
     };
 }
 
+sub expand_uri {
+    my $uri = shift;
+
+    return {
+        type    => 'external',
+        _url    => $uri,
+    };
+}
+
 sub format_datetime {
     my $sql  = shift;
     my $date = RT::Date->new( RT->SystemUser );
